# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.6]
### Fixed
- Tracking middleware log_id return issue.

## [0.1.5]
### Fixed
- Python 3.7 `lru_cache` compatibility with.

## [0.1.4]
### Fixed
- Request data gathering issue on `RawPostDataException` exception.

## [0.1.3]
### Fixed
- Admin `created at` field localization formatting.

## [0.1.2]
### Added
- Logging handler class.
### Fixed
- Views tracker fixes.

## [0.1.0]
Initial version.
